# packages/rapid-development/www/column-edit-2.tcl

ad_page_contract {
    Modifies a column into the rapid development system.

    @author Kevin Scaldeferri (kevin@arsdigita.com)
    @creation-date 2000-12-29
    @cvs-id $Id: column-edit-2.tcl,v 1.1 2001/06/03 00:54:27 dm Exp $
} {
    table_id:integer,notnull
    column_id:integer,notnull
    column_name:notnull
    datatype:notnull
    string_length
    other_string
    default_value
    attribute_p:notnull
    pretty_name
    pretty_plural
    abbrev
    description
    {return_url "table?table_id=$table_id"}
} -validate {
    boolean_attribute_p -requires {attribute_p} {
        if ![regexp {^[tf]$} $attribute_p] {
            ad_complain "Expected attribute_p to be t or f"
        }
    }

    string_length_not_null -requires {datatype} {
        if {$datatype == "string" && [empty_string_p $string_length]} {
            ad_complain "You must provide a length for a string data type."
        }
    }

    string_length_allowed -requires {string_length_not_null} {
        if {$datatype == "string" && ($string_length <= 0 || $string_length > 4000)} {
            ad_complain "The string length must be between 1 and 4000.  You you need a longer string, you must select 'CLOB'."
        }
    }

    other_string_not_null -requires {datatype} {
        if {$datatype == "other" && [empty_string_p $string_length]} {
            ad_complain "You must fill something in if you select 'other'."
        }
    }
}

if {$datatype == "string"} {
    set datatype "varchar2($string_length)"
} elseif {$datatype == "other"} {
    set datatype $other_string
}

if [catch {db_exec_plsql edit_column {
    begin
        rapid_development.edit_column (
            column_id => :column_id,
            column_name => :column_name,
            datatype => :datatype,
            default_value => :default_value,
            attribute_p => :attribute_p,
            pretty_name => :pretty_name,
            pretty_plural => :pretty_plural,
            abbrev => :abbrev,
            description => :description
        );
    end;
}} errmsg] {
    # figure out what the error was

    switch -glob $errmsg {
        {*RD_COLS_TABLE_ID_COL_NAME_UN*} {
            ad_return_complaint 1 "There is already a column with that name in this table"
            return
        }
        default {
            ad_return_complaint 1 "An error occurred which we were unable to identify.  Please notify the site administrator.  Here was the error that we recieved:

            <pre>$errmsg</pre>"
            return
        }
    }
} 


ad_returnredirect $return_url