# packages/rapid-development/www/constraint-add-2.tcl

ad_page_contract {
    Adds a constraint to the rapid development system

    @author Kevin Scaldeferri (kevin@arsdigita.com)
    @creation-date 2000-12-30
    @cvs-id $Id: constraint-add-2.tcl,v 1.1 2001/06/03 00:54:27 dm Exp $
} {
    column_id:integer,notnull
    constraint_id:integer,notnull
    constraint_type:notnull
    constraint_body
    {return_url "zzz"}
} -validate {
    valid_type -requires {constraint_type} {
        switch $constraint_type {
            "primary key" -
            "foreign key" -
            "unique" -
            "not null" -
            "check" {}

            default {ad_complain "Invalid constraint type"}
        }
    }

    body_null_not_null -requires {valid_type constraint_body} {
        switch $constraint_type {
            "primary key" -
            "unique" -
            "not null" {
                if ![empty_string_p $constraint_body] {
                    ad_complain "A $constraint_type constraint should not have anything in the body."
                }
            }

            default {
                if [empty_string_p $constraint_body] {
                    ad_complain "You must provide a body for a $constraint_type constraint."
                }
            }
        }
    }
}

if [string equal $return_url "zzz"] {
    if [db_0or1row table_id "select table_id from rd_columns where column_id = :column_id"] {
        set return_url "table?table_id=$table_id"
    } else {
        set return_url "column?column_id=$column_id"
    }
}

if [catch {db_exec_plsql constraint_add {
    begin
        :1 := rapid_development.add_constraint (
            constraint_id => :constraint_id,
            column_id => :column_id,
            constraint_type => :constraint_type,
            constraint_body => :constraint_body
        );
    end;
}} errmsg] {
    # figure out what went wrong

    switch -glob $errmsg {
        {*RD_CONSTRAINTS_PK*} {
            # a double click
            ad_returnredirect column?column_id=$column_id
            return
        }
        {*RD_CONSTRNTS_COL_TYPE_BODY_UN*} {
            ad_return_complaint 1 "This constraint already seems to exist."
            return
        }
        default {
            ad_return_complaint 1 "An error occurred which we could not identify.  Please let the site administrator know about this.  The error message was:

            <pre>$errmsg</pre>"
            return
        }
    }
}

ad_returnredirect $return_url

    